# vim-addons: command line manager of Vim addons
#
# Copyright (C) 2007 Stefano Zacchiroli
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

module Vim

  class AddonManager

    OVERRIDE_FILE = 'plugin/000-vim-addons.vim'
    HELPZTAGS = '/usr/bin/helpztags'

  end

end
